@@ -52,12 +52,13 @@ class StorageService:
         self,
         file_path: Union[str, Path],
         project_id: str,
-        analysis_node: str,
-        file_category: str,
+        analysis_node: Optional[str] = None,
+        file_category: Optional[str] = None,
         key: Optional[str] = None,
         sample_id: Optional[str] = None,
         description: Optional[str] = None,
         progress_callback: Optional[Callable] = None,
+        base_path: Optional[str] = None,
     ) -> Dict[str, Any]:
         """上传单个文件到 OSS
 
@@ -70,6 +71,7 @@ class StorageService:
             sample_id: 样本 ID（可选）
             description: 文件描述（可选）
             progress_callback: 进度回调函数，签名为 callback(consumed_bytes, total_bytes)
+            base_path: OSS 中的基础路径（可选）
 
         Returns:
             Dict[str, Any]: 上传结果，包含文件信息和 OSS 键名
@@ -90,11 +92,18 @@ class StorageService:
         if not file_path.exists():
             raise FileNotFoundError(f"文件不存在: {file_path}")
 
-        # 构建 OSS 键名：biofile/project_id/analysis_node/[sample_id]/filename
+        # 构建 OSS 键名：biofile/project_id/[base_path/]filename
         if not key:
-            key = self._build_oss_key(
-                project_id, analysis_node, sample_id, file_path.name
-            )
+            # 如果没有指定 base_path，对单文件上传使用 analysis_node/sample_id 作为默认路径
+            if base_path is None:
+                path_parts = []
+                if analysis_node:
+                    path_parts.append(analysis_node)
+                if sample_id:
+                    path_parts.append(sample_id)
+                base_path = "/".join(path_parts) if path_parts else None
+
+            key = self._build_oss_key(project_id, file_path.name, base_path)
 
         # 获取 OSS bucket 并上传文件
         bucket = self._get_oss_bucket(project_id)
@@ -105,8 +114,8 @@ class StorageService:
             file_path,
             key,
             project_id,
-            analysis_node,
-            file_category,
+            analysis_node or "files",
+            file_category or "result",
             sample_id,
             description,
         )
@@ -115,10 +124,11 @@ class StorageService:
         self,
         dir_path: Union[str, Path],
         project_id: str,
-        analysis_node: str,
-        file_category: str,
+        analysis_node: Optional[str] = None,
+        file_category: Optional[str] = None,
         sample_id: Optional[str] = None,
         recursive: bool = True,
+        base_path: Optional[str] = None,
     ) -> List[Dict[str, Any]]:
         """批量上传目录中的所有文件
 
@@ -129,6 +139,7 @@ class StorageService:
             file_category: 文件分类
             sample_id: 样本 ID（可选）
             recursive: 是否递归上传子目录（默认 True）
+            base_path: OSS 中的基础路径（可选）
 
         Returns:
             List[Dict[str, Any]]: 每个文件的上传结果列表
@@ -165,17 +176,18 @@ class StorageService:
         results = []
         for file_path in files:
             try:
-                # 保持相对路径结构
+                # 保持相对路径结构，包含原始目录名
                 relative_path = file_path.relative_to(dir_path)
+                # 添加原始目录名作为前缀
+                dir_name = dir_path.name
+                path_with_dir = f"{dir_name}/{relative_path}"
                 key = self._build_oss_key(
                     project_id,
-                    analysis_node,
-                    sample_id,
-                    str(relative_path),
-                    preserve_structure=True,
+                    path_with_dir,
+                    base_path,
                 )
 
-                # 上传单个文件
+                # 上传单个文件（key已经包含完整路径，不需要再传base_path）
                 result = self.upload_file(
                     file_path, project_id, analysis_node, file_category, key, sample_id
                 )
@@ -243,41 +255,37 @@ class StorageService:
     def _build_oss_key(
         self,
         project_id: str,
-        analysis_node: str,
-        sample_id: Optional[str],
         filename: str,
-        preserve_structure: bool = False,
+        base_path: Optional[str] = None,
     ) -> str:
         """构建 OSS 文件键名
 
         生成规则：
-        - 基础路径：biofile/project_id/analysis_node/[sample_id]/
+        - 基础路径：biofile/project_id/[base_path/]
         - 文件名：添加随机后缀避免冲突
-        - 目录上传：可选择保持原目录结构
+        - 始终保持目录结构
 
         Args:
             project_id: 项目 ID
-            analysis_node: 分析节点名称
-            sample_id: 样本 ID（可选）
             filename: 文件名或相对路径
-            preserve_structure: 是否保持目录结构（用于批量上传）
+            base_path: OSS 中的基础路径（可选）
 
         Returns:
             str: OSS 键名
 
         Example:
-            >>> self._build_oss_key("proj_001", "analysis1", None, "data.csv")
-            "biofile/proj_001/analysis1/data_123456.csv"
+            >>> self._build_oss_key("proj_001", "data.csv", base_path="results")
+            "biofile/proj_001/results/data_123456.csv"
 
-            >>> self._build_oss_key("proj_001", "analysis1", "sample_001", "subdir/file.txt", True)
-            "biofile/proj_001/analysis1/sample_001/subdir/file_123456.txt"
+            >>> self._build_oss_key("proj_001", "subdir/file.txt", "results")
+            "biofile/proj_001/results/subdir/file_123456.txt"
         """
-        parts = ["biofile", project_id, analysis_node]
-        if sample_id:
-            parts.append(sample_id)
+        parts = ["biofile", project_id]
+        if base_path:
+            parts.append(base_path)
 
         path_obj = Path(filename)
-        if preserve_structure and len(path_obj.parts) > 1:
+        if len(path_obj.parts) > 1:
             # 保持目录结构：包含子目录路径
             sub_dirs = "/".join(path_obj.parts[:-1])
             unique_filename = generate_unique_filename(path_obj.stem, path_obj.suffix)
